package com.inspect.exec.mapper;

import com.inspect.exec.domain.PatrolTaskPointExecRecord;
import org.apache.ibatis.annotations.Mapper;

import java.util.List;

@Mapper
public interface PatrolTaskPointExecRecordMapper {
    PatrolTaskPointExecRecord selectPatrolTaskPointExecRecordByPointId(Long pointId);

    List<PatrolTaskPointExecRecord> selectPatrolTaskPointExecRecordList(PatrolTaskPointExecRecord record);

    int insertPatrolTaskPointExecRecord(PatrolTaskPointExecRecord record);

    int updatePatrolTaskPointExecRecord(PatrolTaskPointExecRecord record);

    int deletePatrolTaskPointExecRecordByPointId(Long pointId);

    int deletePatrolTaskPointExecRecordByPointIds(Long[] pointIds);
}
